@@ -41,6 +41,17 @@ test('Not CI', function (t) {
   t.end()
 })
 
+test('Bypass isCI checks with CI set to `false`', function (t) {
+  process.env.CI = 'false'
+
+  clearModule('./')
+  const ci = require('./')
+
+  t.equal(ci.isCI, false)
+
+  t.end()
+})
+
 test('Unknown CI', function (t) {
   process.env.CI = 'true'
 
@@ -113,8 +124,8 @@ test('AppVeyor - Not PR', function (t) {
 })
 
 test('Azure Pipelines - PR', function (t) {
-  process.env.SYSTEM_TEAMFOUNDATIONCOLLECTIONURI = 'https://dev.azure.com/Contoso'
-  process.env.SYSTEM_PULLREQUEST_PULLREQUESTID = '42'
+  process.env.TF_BUILD = 'true'
+  process.env.BUILD_REASON = 'PullRequest'
 
   clearModule('./')
   const ci = require('./')
@@ -125,14 +136,14 @@ test('Azure Pipelines - PR', function (t) {
   t.equal(ci.AZURE_PIPELINES, true)
   assertVendorConstants('AZURE_PIPELINES', ci, t)
 
-  delete process.env.SYSTEM_TEAMFOUNDATIONCOLLECTIONURI
-  delete process.env.SYSTEM_PULLREQUEST_PULLREQUESTID
+  delete process.env.TF_BUILD
+  delete process.env.BUILD_REASON
 
   t.end()
 })
 
 test('Azure Pipelines - Not PR', function (t) {
-  process.env.SYSTEM_TEAMFOUNDATIONCOLLECTIONURI = 'https://dev.azure.com/Contoso'
+  process.env.TF_BUILD = 'true'
 
   clearModule('./')
   const ci = require('./')
@@ -143,7 +154,7 @@ test('Azure Pipelines - Not PR', function (t) {
   t.equal(ci.AZURE_PIPELINES, true)
   assertVendorConstants('AZURE_PIPELINES', ci, t)
 
-  delete process.env.SYSTEM_TEAMFOUNDATIONCOLLECTIONURI
+  delete process.env.TF_BUILD
 
   t.end()
 })
@@ -456,80 +467,6 @@ test('Semaphore - Not PR', function (t) {
   t.end()
 })
 
-test('Shippable - PR', function (t) {
-  process.env.SHIPPABLE = 'true'
-  process.env.IS_PULL_REQUEST = 'true'
-
-  clearModule('./')
-  const ci = require('./')
-
-  t.equal(ci.isCI, true)
-  t.equal(ci.isPR, true)
-  t.equal(ci.name, 'Shippable')
-  t.equal(ci.SHIPPABLE, true)
-  assertVendorConstants('SHIPPABLE', ci, t)
-
-  delete process.env.SHIPPABLE
-  delete process.env.IS_PULL_REQUEST
-
-  t.end()
-})
-
-test('Semaphore - Not PR', function (t) {
-  process.env.SHIPPABLE = 'true'
-  process.env.IS_PULL_REQUEST = 'false'
-
-  clearModule('./')
-  const ci = require('./')
-
-  t.equal(ci.isCI, true)
-  t.equal(ci.isPR, false)
-  t.equal(ci.name, 'Shippable')
-  t.equal(ci.SHIPPABLE, true)
-  assertVendorConstants('SHIPPABLE', ci, t)
-
-  delete process.env.SHIPPABLE
-  delete process.env.IS_PULL_REQUEST
-
-  t.end()
-})
-
-test('Solano CI - PR', function (t) {
-  process.env.TDDIUM = 'true'
-  process.env.TDDIUM_PR_ID = '42'
-
-  clearModule('./')
-  const ci = require('./')
-
-  t.equal(ci.isCI, true)
-  t.equal(ci.isPR, true)
-  t.equal(ci.name, 'Solano CI')
-  t.equal(ci.SOLANO, true)
-  assertVendorConstants('SOLANO', ci, t)
-
-  delete process.env.TDDIUM
-  delete process.env.TDDIUM_PR_ID
-
-  t.end()
-})
-
-test('Solano CI - Not PR', function (t) {
-  process.env.TDDIUM = 'true'
-
-  clearModule('./')
-  const ci = require('./')
-
-  t.equal(ci.isCI, true)
-  t.equal(ci.isPR, false)
-  t.equal(ci.name, 'Solano CI')
-  t.equal(ci.SOLANO, true)
-  assertVendorConstants('SOLANO', ci, t)
-
-  delete process.env.TDDIUM
-
-  t.end()
-})
-
 test('Travis CI - PR', function (t) {
   process.env.TRAVIS = 'true'
   process.env.TRAVIS_PULL_REQUEST = '42'
@@ -613,7 +550,7 @@ test('Vercel - NOW_BUILDER', function (t) {
   const ci = require('./')
 
   t.equal(ci.isCI, true)
-  t.equal(ci.isPR, null)
+  t.equal(ci.isPR, false)
   t.equal(ci.name, 'Vercel')
   t.equal(ci.VERCEL, true)
   assertVendorConstants('VERCEL', ci, t)
@@ -623,19 +560,37 @@ test('Vercel - NOW_BUILDER', function (t) {
   t.end()
 })
 
-test('Vercel - VERCEL_URL', function (t) {
-  process.env.VERCEL_URL = '1'
+test('Vercel - VERCEL', function (t) {
+  process.env.VERCEL = '1'
 
   clearModule('./')
   const ci = require('./')
 
   t.equal(ci.isCI, true)
-  t.equal(ci.isPR, null)
+  t.equal(ci.isPR, false)
   t.equal(ci.name, 'Vercel')
   t.equal(ci.VERCEL, true)
   assertVendorConstants('VERCEL', ci, t)
 
-  delete process.env.VERCEL_URL
+  delete process.env.VERCEL
+
+  t.end()
+})
+
+test('Vercel - PR', function (t) {
+  process.env.VERCEL = '1'
+  process.env.VERCEL_GIT_PULL_REQUEST_ID = '23'
+
+  clearModule('./')
+  const ci = require('./')
+
+  t.equal(ci.isCI, true)
+  t.equal(ci.isPR, true)
+  t.equal(ci.name, 'Vercel')
+  t.equal(ci.VERCEL, true)
+  assertVendorConstants('VERCEL', ci, t)
+
+  delete process.env.VERCEL
 
   t.end()
 })
@@ -893,10 +848,165 @@ test('Heroku', function (t) {
   t.end()
 })
 
+test('Sourcehit', function (t) {
+  process.env.CI_NAME = 'sourcehut'
+
+  clearModule('./')
+  const ci = require('./')
+
+  t.equal(ci.isCI, true)
+  t.equal(ci.name, 'Sourcehut')
+  t.equal(ci.SOURCEHUT, true)
+  assertVendorConstants('SOURCEHUT', ci, t)
+
+  delete process.env.CI_NAME
+
+  t.end()
+})
+
+test('ReleaseHub', function (t) {
+  process.env.RELEASE_BUILD_ID = '1a'
+
+  clearModule('./')
+  const ci = require('./')
+
+  t.equal(ci.isCI, true)
+  t.equal(ci.name, 'ReleaseHub')
+  t.equal(ci.RELEASEHUB, true)
+  assertVendorConstants('RELEASEHUB', ci, t)
+
+  delete process.env.RELEASE_BUILD_ID
+
+  t.end()
+})
+
+test('Gitea Actions', function (t) {
+  process.env.GITEA_ACTIONS = 'true'
+
+  clearModule('./')
+  const ci = require('./')
+
+  t.equal(ci.isCI, true)
+  t.equal(ci.name, 'Gitea Actions')
+  t.equal(ci.GITEA_ACTIONS, true)
+  assertVendorConstants('GITEA_ACTIONS', ci, t)
+
+  delete process.env.GITEA_ACTIONS
+
+  t.end()
+})
+
+test('Agola CI', function (t) {
+  process.env.AGOLA_GIT_REF = 'true'
+  process.env.AGOLA_PULL_REQUEST_ID = ''
+
+  clearModule('./')
+  const ci = require('./')
+
+  t.equal(ci.isCI, true)
+  t.equal(ci.isPR, false)
+  t.equal(ci.name, 'Agola CI')
+  t.equal(ci.AGOLA, true)
+  assertVendorConstants('AGOLA', ci, t)
+
+  delete process.env.AGOLA_GIT_REF
+  delete process.env.AGOLA_PULL_REQUEST_ID
+
+  t.end()
+})
+
+test('Agola CI - PR', function (t) {
+  process.env.AGOLA_GIT_REF = 'true'
+  process.env.AGOLA_PULL_REQUEST_ID = '12'
+
+  clearModule('./')
+  const ci = require('./')
+
+  t.equal(ci.isCI, true)
+  t.equal(ci.isPR, true)
+  t.equal(ci.name, 'Agola CI')
+  t.equal(ci.AGOLA, true)
+  assertVendorConstants('AGOLA', ci, t)
+
+  delete process.env.AGOLA_GIT_REF
+  delete process.env.AGOLA_PULL_REQUEST_ID
+
+  t.end()
+})
+
+test('Vela', function (t) {
+  process.env.VELA = 'true'
+  process.env.VELA_PULL_REQUEST = '2'
+
+  clearModule('./')
+  const ci = require('./')
+
+  t.equal(ci.isCI, true)
+  t.equal(ci.isPR, false)
+  t.equal(ci.name, 'Vela')
+  t.equal(ci.VELA, true)
+  assertVendorConstants('VELA', ci, t)
+
+  delete process.env.VELA
+  delete process.env.VELA_PULL_REQUEST
+
+  t.end()
+})
+
+test('Vela - PR', function (t) {
+  process.env.VELA = 'true'
+  process.env.VELA_PULL_REQUEST = '1'
+
+  clearModule('./')
+  const ci = require('./')
+
+  t.equal(ci.isCI, true)
+  t.equal(ci.isPR, true)
+  t.equal(ci.name, 'Vela')
+  t.equal(ci.VELA, true)
+  assertVendorConstants('VELA', ci, t)
+
+  delete process.env.VELA
+  delete process.env.VELA_PULL_REQUEST
+
+  t.end()
+})
+
+test('Prow', function (t) {
+  process.env.PROW_JOB_ID = '123'
+
+  clearModule('./')
+  const ci = require('./')
+
+  t.equal(ci.isCI, true)
+  t.equal(ci.name, 'Prow')
+  t.equal(ci.PROW, true)
+  assertVendorConstants('PROW', ci, t)
+
+  delete process.env.PROW_JOB_ID
+
+  t.end()
+})
+
+test('Earthly CI', function (t) {
+  process.env.EARTHLY_CI = 'true'
+
+  clearModule('./')
+  const ci = require('./')
+
+  t.equal(ci.isCI, true)
+  t.equal(ci.name, 'Earthly')
+  t.equal(ci.EARTHLY, true)
+  assertVendorConstants('EARTHLY', ci, t)
+
+  delete process.env.EARTHLY_CI
+
+  t.end()
+})
+
 function assertVendorConstants (expect, ci, t) {
   ci._vendors.forEach(function (constant) {
-    let bool = constant === expect
-    bool = (expect === 'SOLANO' && constant === 'TDDIUM') || bool // support deprecated option
+    const bool = constant === expect
     t.equal(ci[constant], bool, 'ci.' + constant)
   })
 }
